==> fox0.99_0.99.87.orig.tar.gz: fox-0.99.87/src/FXGLCone.cpp <==
/********************************************************************************
*                                                                               *
*                      O p e n G L   C o n e   O b j e c t                      *
*                                                                               *
*********************************************************************************
* Copyright (C) 1999 by Jeroen van der Zijp.   All Rights Reserved.             *
*********************************************************************************
* Contributed by: Angel-Ventura Mendo Gomez <ventura@labri.u-bordeaux.fr>       *
*********************************************************************************
* This library is free software; you can redistribute it and/or                 *
* modify it under the terms of the GNU Library General Public                   *
* License as published by the Free Software Foundation; either                  *
* version 2 of the License, or (at your option) any later version.              *
*                                                                               *
* This library is distributed in the hope that it will be useful,               *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
* Library General Public License for more details.                              *
*                                                                               *
* You should have received a copy of the GNU Library General Public             *
* License along with this library; if not, write to the Free                    *
* Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.            *
*********************************************************************************
* $Id: FXGLCone.cpp,v 1.2 1999/10/12 13:17:56 jeroen Exp $                      *
********************************************************************************/
#include "xincs.h"
#include "fxdefs.h"
#include "FXStream.h"
#include "FXVec.h"
#include "FXHVec.h"
#include "FXQuat.h"
#include "FXHMat.h"
#include "FXRange.h"
#include "FXString.h"
#include "FXObject.h"
#include "FXDict.h"
#include "FXRegistry.h"
#include "FXAccelTable.h"
#include "FXObjectList.h"
#include "FXApp.h"
#include "FXId.h"
#include "FXDrawable.h"
#include "FXWindow.h"
#include "FXCursor.h"
#include "FXGLCanvas.h"
#include "FXDC.h"
#include "FXDCPrint.h"
#include "FXGLViewer.h"
#include "FXGLObject.h"
#include "FXComposite.h"
#include "FXShell.h"
#include "FXTooltip.h"
#include "FXGLShape.h"
#include "FXGLCone.h"

// GLU versions prior to 1.1 have GLUquadric
#if !defined(GLU_VERSION_1_1) && !defined(GLU_VERSION_1_2) && !defined(GLU_VERSION_1_3)
#define GLUquadricObj GLUquadric
#endif


// Cone fidelity
#define FXGLCONE_SLICES_NUMBER		20
#define FXGLCONE_STACKS_NUMBER		20
#define FXGLCONE_LOOPS			4

/*******************************************************************************/

  
// Object implementation
FXIMPLEMENT(FXGLCone,FXGLShape,NULL,0)


// Create cone
FXGLCone::FXGLCone():height(1.0),radius(1.0){ 
  range[0][0]=-radius; range[0][1]=radius;
  range[1][0]=0;       range[1][1]=height;
  range[2][0]=-radius; range[2][1]=radius;
  }


// Create cone
FXGLCone::FXGLCone(FXfloat x,FXfloat y,FXfloat z,FXfloat h,FXfloat r):
  FXGLShape(x,y,z,SHADING_SMOOTH|STYLE_SURFACE),height(h),radius(r){
  range[0][0]=-radius; range[0][1]=radius;
  range[1][0]=0;       range[1][1]=height;
  range[2][0]=-radius; range[2][1]=radius;
  }


// Create cone
FXGLCone::FXGLCone(FXfloat x,FXfloat y,FXfloat z,FXfloat h, FXfloat r,const FXMaterial& mtl):
  FXGLShape(x,y,z,SHADING_SMOOTH|STYLE_SURFACE,mtl,mtl),height(h),radius(r){
  range[0][0]=-radius; range[0][1]=radius;
  range[1][0]=0;       range[1][1]=height;
  range[2][0]=-radius; range[2][1]=radius;
  }


// Draw
void FXGLCone::drawshape(FXGLViewer*){
#ifdef HAVE_OPENGL
  GLUquadricObj* quad=gluNewQuadric();
  gluQuadricDrawStyle(quad,(GLenum)GLU_FILL);
  /*
    gluQuadricNormals(quad,(GLenum)GLU_SMOOTH);
    gluQuadricOrientation(quad,(GLenum)GLU_OUTSIDE);
  */
  glPushMatrix();
  glRotatef(-90,1,0,0);
  gluCylinder(quad,radius,0,height,FXGLCONE_SLICES_NUMBER,FXGLCONE_STACKS_NUMBER);
  gluQuadricOrientation(quad,(GLenum)GLU_INSIDE);
  gluDisk(quad,0,radius,FXGLCONE_SLICES_NUMBER,FXGLCONE_LOOPS);
  gluDeleteQuadric(quad);
  glPopMatrix();
#endif
  }


// Save object to stream
void FXGLCone::save(FXStream& store) const {
  FXGLShape::save(store);
  store << height << radius;
  }

      
// Load object from stream
void FXGLCone::load(FXStream& store){
  FXGLShape::load(store);
  store >> height >> radius;
  }

==> fox0.99_0.99.175.orig.tar.gz: fox-0.99.175/src/FXGLCone.cpp <==
/********************************************************************************
*                                                                               *
*                      O p e n G L   C o n e   O b j e c t                      *
*                                                                               *
*********************************************************************************
* Copyright (C) 1999,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
*********************************************************************************
* Contributed by: Angel-Ventura Mendo Gomez <ventura@labri.u-bordeaux.fr>       *
*********************************************************************************
* This library is free software; you can redistribute it and/or                 *
* modify it under the terms of the GNU Lesser General Public                    *
* License as published by the Free Software Foundation; either                  *
* version 2.1 of the License, or (at your option) any later version.            *
*                                                                               *
* This library is distributed in the hope that it will be useful,               *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
* Lesser General Public License for more details.                               *
*                                                                               *
* You should have received a copy of the GNU Lesser General Public              *
* License along with this library; if not, write to the Free Software           *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
*********************************************************************************
* $Id: FXGLCone.cpp,v 1.8 2001/04/27 14:30:32 jeroen Exp $                      *
********************************************************************************/
#include "xincs.h"
#include "fxver.h"
#include "fxdefs.h"
#include "FXStream.h"
#include "FXVec.h"
#include "FXHVec.h"
#include "FXQuat.h"
#include "FXHMat.h"
#include "FXRange.h"
#include "FXString.h"
#include "FXSize.h"
#include "FXPoint.h"
#include "FXRectangle.h"
#include "FXObject.h"
#include "FXDict.h"
#include "FXSettings.h"
#include "FXRegistry.h"
#include "FXAccelTable.h"
#include "FXObjectList.h"
#include "FXApp.h"
#include "FXId.h"
#include "FXDrawable.h"
#include "FXWindow.h"
#include "FXCursor.h"
#include "FXCanvas.h"
#include "FXGLCanvas.h"
#include "FXDC.h"
#include "FXDCPrint.h"
#include "FXGLViewer.h"
#include "FXGLObject.h"
#include "FXComposite.h"
#include "FXShell.h"
#include "FXTooltip.h"
#include "FXGLShape.h"
#include "FXGLCone.h"

// GLU versions prior to 1.1 have GLUquadric
#if !defined(GLU_VERSION_1_1) && !defined(GLU_VERSION_1_2) && !defined(GLU_VERSION_1_3)
#define GLUquadricObj GLUquadric
#endif


// Cone fidelity
#define FXGLCONE_SLICES_NUMBER		20
#define FXGLCONE_STACKS_NUMBER		20
#define FXGLCONE_LOOPS			4

/*******************************************************************************/


// Object implementation
FXIMPLEMENT(FXGLCone,FXGLShape,NULL,0)


// Create cone
FXGLCone::FXGLCone():height(1.0),radius(1.0f){
  FXTRACE((100,"FXGLCone::FXGLCone\n"));
  range[0][0]=-radius; range[0][1]=radius;
  range[1][0]=0;       range[1][1]=height;
  range[2][0]=-radius; range[2][1]=radius;
  }


// Create cone
FXGLCone::FXGLCone(FXfloat x,FXfloat y,FXfloat z,FXfloat h,FXfloat r):
  FXGLShape(x,y,z,SHADING_SMOOTH|STYLE_SURFACE),height(h),radius(r){
  FXTRACE((100,"FXGLCone::FXGLCone\n"));
  range[0][0]=-radius; range[0][1]=radius;
  range[1][0]=0;       range[1][1]=height;
  range[2][0]=-radius; range[2][1]=radius;
  }


// Create cone
FXGLCone::FXGLCone(FXfloat x,FXfloat y,FXfloat z,FXfloat h, FXfloat r,const FXMaterial& mtl):
  FXGLShape(x,y,z,SHADING_SMOOTH|STYLE_SURFACE,mtl,mtl),height(h),radius(r){
  FXTRACE((100,"FXGLCone::FXGLCone\n"));
  range[0][0]=-radius; range[0][1]=radius;
  range[1][0]=0;       range[1][1]=height;
  range[2][0]=-radius; range[2][1]=radius;
  }


// Copy constructor
FXGLCone::FXGLCone(const FXGLCone& orig):FXGLShape(orig){
  FXTRACE((100,"FXGLCone::FXGLCone\n"));
  height=orig.height;
  radius=orig.radius;
  }


// Draw
void FXGLCone::drawshape(FXGLViewer*){
#ifdef HAVE_OPENGL
  GLUquadricObj* quad=gluNewQuadric();
  gluQuadricDrawStyle(quad,(GLenum)GLU_FILL);
  /*
    gluQuadricNormals(quad,(GLenum)GLU_SMOOTH);
    gluQuadricOrientation(quad,(GLenum)GLU_OUTSIDE);
  */
  glPushMatrix();
  glRotatef(-90,1,0,0);
  gluCylinder(quad,radius,0,height,FXGLCONE_SLICES_NUMBER,FXGLCONE_STACKS_NUMBER);
  gluQuadricOrientation(quad,(GLenum)GLU_INSIDE);
  gluDisk(quad,0,radius,FXGLCONE_SLICES_NUMBER,FXGLCONE_LOOPS);
  gluDeleteQuadric(quad);
  glPopMatrix();
#endif
  }


// Copy this object
FXGLObject* FXGLCone::copy(){
  return new FXGLCone(*this);
  }


// Save object to stream
void FXGLCone::save(FXStream& store) const {
  FXGLShape::save(store);
  store << height << radius;
  }


// Load object from stream
void FXGLCone::load(FXStream& store){
  FXGLShape::load(store);
  store >> height >> radius;
  }


// Destroy
FXGLCone::~FXGLCone(){
  FXTRACE((100,"FXGLCone::~FXGLCone\n"));
  }
